FaceOverlayPlatform class abstract

The interface that platform-specific implementations of face_overlay must extend.

Inheritance
  • Object
  • PlatformInterface
  • FaceOverlayPlatform
Implementers

Constructors

FaceOverlayPlatform()
Constructs a FaceOverlayPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
Returns the platform version string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FaceOverlayPlatform
The default instance of FaceOverlayPlatform to use.
getter/setter pair